/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.database.filters;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;

import org.apache.commons.collections4.MapUtils;
import org.dussan.vaadin.dvirtual.database.columns.ServersGroupColumns;
import org.dussan.vaadin.dvirtual.database.data.ServerData_;
import org.dussan.vaadin.dvirtual.database.data.ServersGroupData;
import org.dussan.vaadin.dvirtual.database.data.ServersGroupData_;

public class ServersGroupFilter
    implements Serializable
{

    private static final long serialVersionUID = -6432256097960958237L;

    private static final String FILTER = "%%%s%%";

    public static final <T> CriteriaQuery<T> addFilter( CriteriaBuilder criteriaBuilder, CriteriaQuery<T> criteriaQuery, Root<ServersGroupData> serversGroup,
                                                        Map<ServersGroupColumns, String> filterMap )
    {
        if ( MapUtils.isNotEmpty( filterMap ) )
        {
            List<Predicate> predicates = new ArrayList<>();
            for ( Map.Entry<ServersGroupColumns, String> filter : filterMap.entrySet() )
            {
                switch ( filter.getKey() )
                {
                    case ENABLED:
                        Boolean enabled = Boolean.parseBoolean( filter.getValue() );
                        if ( enabled )
                        {
                            predicates.add( criteriaBuilder.isTrue( serversGroup.get( ServersGroupData_.enabled ) ) );
                        }
                        else
                        {
                            predicates.add( criteriaBuilder.isFalse( serversGroup.get( ServersGroupData_.enabled ) ) );
                        }
                        break;
                    case NAME:
                        predicates.add( criteriaBuilder.like( criteriaBuilder.lower( serversGroup.get( ServersGroupData_.name ) ), String.format( FILTER, filter.getValue()
                                                                                                                                                                .toLowerCase() ) ) );
                        break;
                    case NOTE:
                        predicates.add( criteriaBuilder.like( criteriaBuilder.lower( serversGroup.get( ServersGroupData_.note ) ), String.format( FILTER, filter.getValue()
                                                                                                                                                                .toLowerCase() ) ) );
                        break;
                    case SERVER:
                        predicates.add( criteriaBuilder.like( criteriaBuilder.lower( serversGroup.join( ServersGroupData_.serverDatas )
                                                                                                 .get( ServerData_.name ) ),
                                                              String.format( FILTER, filter.getValue()
                                                                                           .toLowerCase() ) ) );
                        break;
                    default:
                        // nothing to do
                        break;
                }
            }
            return criteriaQuery.where( criteriaBuilder.and( predicates.toArray( Predicate[]::new ) ) );
        }
        return criteriaQuery;
    }

}
