/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.database.orders;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Order;
import javax.persistence.criteria.Root;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.dussan.vaadin.dvirtual.database.columns.ApplicationColumns;
import org.dussan.vaadin.dvirtual.database.data.ApplicationData;
import org.dussan.vaadin.dvirtual.database.data.ApplicationData_;

public class ApplicationOrder
    implements Serializable
{

    private static final long serialVersionUID = 8235225648999394805L;

    public static final CriteriaQuery<ApplicationData> addOrder( CriteriaBuilder criteriaBuilder, CriteriaQuery<ApplicationData> criteriaQuery, Root<ApplicationData> application, List<String> orders )
    {
        if ( CollectionUtils.isNotEmpty( orders ) )
        {
            List<Order> criteriaOrders = new ArrayList<>();
            for ( String order : orders )
            {
                if ( StringUtils.equals( order, ApplicationColumns.COMMAND.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( application.get( ApplicationData_.command ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.COMMAND.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( application.get( ApplicationData_.command ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.COMMAND_OPTIONS.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( application.get( ApplicationData_.command ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.COMMAND_OPTIONS.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( application.get( ApplicationData_.command ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.ENABLED.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( application.get( ApplicationData_.enabled ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.ENABLED.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( application.get( ApplicationData_.enabled ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.NAME.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( application.get( ApplicationData_.name ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.NAME.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( application.get( ApplicationData_.name ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.NOTE.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( application.get( ApplicationData_.note ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.NOTE.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( application.get( ApplicationData_.note ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.ONE_INSTANCE.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( application.get( ApplicationData_.oneInstance ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.ONE_INSTANCE.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( application.get( ApplicationData_.oneInstance ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.SERVER_AUTO_SELECT.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( application.get( ApplicationData_.serverAutoSelect ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationColumns.SERVER_AUTO_SELECT.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( application.get( ApplicationData_.serverAutoSelect ) ) );
                }
            }
            return criteriaQuery.orderBy( criteriaOrders );
        }
        else
        {
            return criteriaQuery.orderBy( criteriaBuilder.asc( application.get( ApplicationData_.name ) ) );
        }
    }

}
