/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.database.orders;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Order;
import javax.persistence.criteria.Root;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.dussan.vaadin.dvirtual.database.columns.ServerColumns;
import org.dussan.vaadin.dvirtual.database.data.ServerData;
import org.dussan.vaadin.dvirtual.database.data.ServerData_;

public class ServerOrder
    implements Serializable
{

    private static final long serialVersionUID = 1844343669649842526L;

    public static final CriteriaQuery<ServerData> addOrder( CriteriaBuilder criteriaBuilder, CriteriaQuery<ServerData> criteriaQuery, Root<ServerData> server, List<String> orders )
    {
        if ( CollectionUtils.isNotEmpty( orders ) )
        {
            List<Order> criteriaOrders = new ArrayList<>();
            for ( String order : orders )
            {
                if ( StringUtils.equals( order, ServerColumns.ADDRESS.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( server.get( ServerData_.address ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.ADDRESS.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( server.get( ServerData_.address ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.ENABLED.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( server.get( ServerData_.enabled ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.ENABLED.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( server.get( ServerData_.enabled ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.MAX_USERS.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( server.get( ServerData_.maxUsers ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.MAX_USERS.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( server.get( ServerData_.maxUsers ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.NAME.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( server.get( ServerData_.name ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.NAME.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( server.get( ServerData_.name ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.NOTE.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( server.get( ServerData_.note ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.NOTE.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( server.get( ServerData_.note ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.SSH_PORT.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( server.get( ServerData_.sshPort ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.SSH_PORT.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( server.get( ServerData_.sshPort ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.XPRA_MAX_PORT.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( server.get( ServerData_.xpraMaxPort ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.XPRA_MAX_PORT.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( server.get( ServerData_.xpraMaxPort ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.XPRA_MIN_PORT.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( server.get( ServerData_.xpraMinPort ) ) );
                }
                else if ( StringUtils.equals( order, ServerColumns.XPRA_MIN_PORT.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( server.get( ServerData_.xpraMinPort ) ) );
                }
            }
            return criteriaQuery.orderBy( criteriaOrders );
        }
        else
        {
            return criteriaQuery.orderBy( criteriaBuilder.asc( server.get( ServerData_.name ) ) );
        }
    }

}
