/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.info;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

import org.apache.commons.collections4.MapUtils;

public class KeyboardKeyName
    implements Serializable
{

    private static final long serialVersionUID = 874591114926729065L;

    private Map<String, String> keyNames = new HashMap<>();

    public KeyboardKeyName()
    {
        keyNames.put( "Escape", "Escape" );
        keyNames.put( "Tab", "Tab" );
        keyNames.put( "CapsLock", "Caps_Lock" );
        keyNames.put( "ShiftLeft", "Shift_L" );
        keyNames.put( "ControlLeft", "Control_L" );
        keyNames.put( "MetaLeft", "Meta_L" );
        keyNames.put( "AltLeft", "Alt_L" );
        keyNames.put( "Space", "space" );
        keyNames.put( "AltRight", "Alt_R" );
        keyNames.put( "MetaRight", "Meta_R" );
        keyNames.put( "ContextMenu", "Menu_R" );
        keyNames.put( "ControlRight", "Control_L" );
        keyNames.put( "ShiftRight", "Shift_R" );
        keyNames.put( "Enter", "Return" );
        keyNames.put( "Backspace", "BackSpace" );
        // Special keys,
        keyNames.put( "ScrollLock", "Scroll_Lock" );
        keyNames.put( "Pause", "Pause" );
        keyNames.put( "NumLock", "Num_Lock" );
        // Arrow pad,
        keyNames.put( "Insert", "Insert" );
        keyNames.put( "Home", "Home" );
        keyNames.put( "PageUp", "Prior" );
        keyNames.put( "Delete", "Delete" );
        keyNames.put( "End", "End" );
        keyNames.put( "PageDown", "Next" );
    }

    public boolean contains( String keyName )
    {
        return Objects.nonNull( MapUtils.getString( keyNames, keyName ) );
    }

    public String get( String keyName )
    {
        return MapUtils.getString( keyNames, keyName );
    }

}
