/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.info;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

import org.apache.commons.collections4.MapUtils;

public class KeyboardNumpadName
    implements Serializable
{

    private static final long serialVersionUID = -1065506852106493001L;

    private Map<String, String> numpadName = new HashMap<>();

    public KeyboardNumpadName()
    {
        // Num pad:
        numpadName.put( "NumpadDivide", "KP_Divide" );
        numpadName.put( "NumpadMultiply", "KP_Multiply" );
        numpadName.put( "NumpadSubstract", "KP_Substract" );
        numpadName.put( "NumpadAdd", "KP_Add" );
        numpadName.put( "NumpadEnter", "KP_Enter" );
        numpadName.put( "NumpadDecimal", "KP_Decimal" );
        // Num_Lock off:
        numpadName.put( "Insert", "KP_Insert" );
        numpadName.put( "End", "KP_End" );
        numpadName.put( "ArrowDown", "KP_Down" );
        numpadName.put( "PageDown", "KP_Next" );
        numpadName.put( "ArrowLeft", "KP_Left" );
        numpadName.put( "Clear", "KP_Begin" );
        numpadName.put( "ArrowRight", "KP_Right" );
        numpadName.put( "Home", "KP_Home" );
        numpadName.put( "ArrowUp", "KP_Up" );
        numpadName.put( "PageUp", "KP_Prior" );
    }

    public boolean contains( String keyString )
    {
        return Objects.nonNull( MapUtils.getString( numpadName, keyString ) );
    }

    public String get( String keyString )
    {
        return MapUtils.getString( numpadName, keyString );
    }

}
