/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.runners;

import java.util.concurrent.TimeUnit;

import org.dussan.vaadin.dvirtual.utils.TooltipConfigurationUtil;

import com.vaadin.flow.component.Component;
import com.vaadin.flow.component.UI;

import dev.mett.vaadin.tooltip.Tooltips;
import dev.mett.vaadin.tooltip.config.TC_PLACEMENT;

public class TooltipRunner
    implements Runnable
{

    private static final int MAX_WAIT_INTERVAL = 1000; // milliseconds

    private static final int SLEEP_INTERVAL = 100; // milliseconds

    private String message = null;

    private Component component = null;

    private UI ui = null;

    public TooltipRunner( Component component, String message, UI ui )
    {
        this.component = component;
        this.message = message;
        this.ui = ui;
    }

    @Override
    public void run()
    {
        try
        {
            for ( int timer = 0; timer < MAX_WAIT_INTERVAL; timer += SLEEP_INTERVAL )
            {
                TimeUnit.MILLISECONDS.sleep( SLEEP_INTERVAL );
                if ( component.isAttached() )
                {
                    ui.getSession()
                      .lock();
                    ui.access( () -> {
                        TooltipConfigurationUtil tooltipConfigurationUtil = new TooltipConfigurationUtil( message );
                        tooltipConfigurationUtil.setPlacement( TC_PLACEMENT.TOP );
                        Tooltips.get( ui )
                                .setTooltip( component, tooltipConfigurationUtil );
                        ui.push();
                    } );
                    ui.getSession()
                      .unlock();
                    break;
                }
            }
        }
        catch ( InterruptedException exception )
        {
            Thread.currentThread()
                  .interrupt();
        }
    }

}
