/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.ui;

import org.apache.commons.lang3.RandomStringUtils;
import org.apache.commons.lang3.StringUtils;

import com.vaadin.flow.component.html.Div;
import com.vaadin.flow.component.html.Image;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;

public class CanvasUI
    extends VerticalLayout
{

    private static final long serialVersionUID = -4925143653707285512L;

    private static final int RANDOM_STRING_LENGTH = 12;

    private static final String ATTRIBUTE_CONTEXT_MENU = "oncontextmenu";

    private static final String ATTRIBUTE_CONTEXT_MENU_VALUE = "return false;";

    private static final String CANVAS_TESTING_ID = "testing-";

    private static final String CLASS_CANVAS_DIV = "canvas-div";

    private static final String CLASS_CANVAS_UI = "canvas-ui";

    private static final String IMAGE = "frontend/img/dVirtual.png";

    private static final String IMAGE_ALT = StringUtils.EMPTY;

    private String canvasId = null;

    private Div canvasDiv = null;

    public CanvasUI( boolean testing )
    {
        setMargin( false );
        setPadding( false );
        setSpacing( false );
        addClassName( CLASS_CANVAS_UI );

        Image image = new Image( IMAGE, IMAGE_ALT );
        add( image );
        setHorizontalComponentAlignment( Alignment.CENTER, image );
        setJustifyContentMode( JustifyContentMode.CENTER );

        // canvas id
        canvasId = RandomStringUtils.randomNumeric( RANDOM_STRING_LENGTH );
        canvasId = testing ? StringUtils.join( CANVAS_TESTING_ID, canvasId ) : canvasId;

        // canvas div element
        canvasDiv = new Div();
        canvasDiv.setId( canvasId );
        canvasDiv.setSizeFull();
        canvasDiv.getElement()
                 .setAttribute( ATTRIBUTE_CONTEXT_MENU, ATTRIBUTE_CONTEXT_MENU_VALUE );
        canvasDiv.addClassName( CLASS_CANVAS_DIV );
        add( canvasDiv );
        expand( canvasDiv );
    }

    public Div getCanvasDiv()
    {
        return canvasDiv;
    }

    public String getCanvasId()
    {
        return canvasId;
    }

}
