/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.xpra.info;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import org.apache.commons.lang3.StringUtils;

public enum RgbFormat
{
    RGBX( "RGBX" ), RGBA( "RGBA" ), UNDEFINED( "undefined" );

    private String format;

    RgbFormat()
    {
        format = name();
    }

    RgbFormat( String format )
    {
        this.format = format;
    }

    public static RgbFormat getFormat( String format )
    {
        for ( RgbFormat t : RgbFormat.values() )
        {
            if ( StringUtils.equalsIgnoreCase( t.name(), format ) )
            {
                return t;
            }
        }
        return UNDEFINED;
    }

    public static RgbFormat[] getAllFormats()
    {
        List<RgbFormat> formats = new ArrayList<>();
        for ( RgbFormat format : RgbFormat.values() )
        {
            if ( !format.equals( UNDEFINED ) )
            {
                formats.add( format );
            }
        }
        return formats.toArray( RgbFormat[]::new );
    }

    public static List<String> toStringList( RgbFormat[] formats )
    {
        List<String> formatList = new ArrayList<>();
        if ( Objects.nonNull( formats ) && formats.length > 0 )
        {
            for ( RgbFormat format : formats )
            {
                if ( !format.equals( UNDEFINED ) )
                {
                    formatList.add( format.toString() );
                }
            }
        }
        return formatList;
    }

    @Override
    public String toString()
    {
        return format;
    }

}
