/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.base;

import java.io.Serializable;

public class ClientCapabilities
    implements Serializable
{

    private static final long serialVersionUID = -6974322635654223133L;

    public static final double DPI_FACTOR = 25.4;

    public static final String AUTO_REFRESH_DELAY = "auto_refresh_delay";

    public static final String BELL = "bell";

    public static final String BENCODE = "bencode";

    public static final String BROTLI = "brotli";

    public static final String CHUNKED_COMPRESSION = "chunked_compression";

    public static final String CLIENT_TYPE = "client_type";

    public static final String CLIPBOARD = "clipboard";

    public static final String CLIPBOARD_CONTENTS_SLICE_FIX = "clipboard.contents-slice-fix";

    public static final String CLIPBOARD_GREEDY = "clipboard.greedy";

    public static final String CLIPBOARD_PREFERRED_TARGETS = "clipboard.preferred-targets";

    public static final String CLIPBOARD_SELECTIONS = "clipboard.selections";

    public static final String CLIPBOARD_WANT_TARGETS = "clipboard.want_targets";

    public static final String COMPRESSION_LEVEL = "compression_level";

    public static final String CURSORS = "cursors";

    public static final String DESKTOP_MODE_SIZE = "desktop_mode_size";

    public static final String DESKTOP_SIZE = "desktop_size";

    public static final String DPI = "dpi";

    public static final String ENCODING_CLIENT_OPTIONS = "encoding.client_options";

    public static final String ENCODING_COLOR_GAMUT = "encoding.color-gamut";

    public static final String ENCODING_EOS = "encoding.eos";

    public static final String ENCODING_FLUSH = "encoding.flush";

    public static final String ENCODING_GENERIC = "encoding.generic";

    public static final String ENCODING_H264_CABAC = "encoding.h264.cabac";

    public static final String ENCODING_H264_DEBLOCKING_FILTER = "encoding.h264.deblocking-filter";

    public static final String ENCODING_H264_FAST_DECODE = "encoding.h264.fast-decode";

    public static final String ENCODING_H264_MP4_SCORE_DELTA = "encoding.h264+mp4.score-delta";

    public static final String ENCODING_H264_MP4_YUV420P_LEVEL = "encoding.h264+mp4.YUV420P.level";

    public static final String ENCODING_H264_MP4_YUV420P_PROFILE = "encoding.h264+mp4.YUV420P.profile";

    public static final String ENCODING_H264_SCORE_DELTA = "encoding.h264.score-delta";

    public static final String ENCODING_H264_YUV420P_LEVEL = "encoding.h264.YUV420P.level";

    public static final String ENCODING_H264_YUV420P_PROFILE = "encoding.h264.YUV420P.profile";

    public static final String ENCODING_ICONS_MAX_SIZE = "encoding.icons.max_size";

    public static final String ENCODING_MIN_QUALITY = "encoding.min-quality";

    public static final String ENCODING_MIN_SPEED = "encoding.min-speed";

    public static final String ENCODING_MPEG4_MP4_SCORE_DELTA = "encoding.mpeg4+mp4.score-delta";

    public static final String ENCODING_NON_SCROLL = "encoding.non-scroll";

    public static final String ENCODING_RGB_LZ4 = "encoding.rgb_lz4";

    public static final String ENCODING_RGB_ZLIB = "encoding.rgb_zlib";

    public static final String ENCODING_RGB24_ZLIB = "encoding.rgb24zlib";

    public static final String ENCODING_SCROLLING = "encoding.scrolling";

    public static final String ENCODING_TRANSPARENCY = "encoding.transparency";

    public static final String ENCODING_X264_YUV420P_PROFILE = "encoding.x264.YUV420P.profile";

    public static final String ENCODING_WP8_WEBM_SCORE_DELTA = "encoding.vp8+webm.score-delta";

    public static final String ENCODINGS = "encodings";

    public static final String ENCODINGS_CORE = "encodings.core";

    public static final String ENCODINGS_CURSOR = "encodings.cursor";

    public static final String ENCODING_FULL_CSC_MODES = "encoding.full_csc_modes";

    public static final String ENCODINGS_PACKET = "encodings.packet";

    public static final String ENCODINGS_RGB_FORMATS = "encodings.rgb_formats";

    public static final String ENCODINGS_WINDOW_ICON = "encodings.window-icon";

    public static final String FILE_SIZE_LIMIT = "file-size-limit";

    public static final String FILE_TRANSFER = "file-transfer";

    public static final String KEYBOARD = "keyboard";

    public static final String LZ4 = "lz4";

    public static final String LZ4_JS_VERSION = "lz4.js.version";

    public static final String LZO = "lzo";

    public static final String METADATA_SUPPORTED = "metadata.supported";

    public static final String NAMED_CURSORS = "named_cursors";

    public static final String NOTIFICATIONS = "notifications";

    public static final String PLATFORM = "platform";

    public static final String PRINTING = "printing";

    public static final String RENCODE = "rencode";

    public static final String SCREEN_CANVAS = "Canvas";

    public static final String SCREEN_HTML = "HTML";

    public static final String SCREEN_SIZES = "screen_sizes";

    public static final String SERVER_WINDOW_RESIZE = "server-window-resize";

    public static final String SHARE = "share";

    public static final String SYSTEM_TRAY = "system_tray";

    public static final String UUID = "uuid";

    public static final String VERSION = "version";

    public static final String WINDOW_RAISE = "window.raise";

    public static final String WINDOWS = "windows";

    public static final String XKBMAP_KEYCODES = "xkbmap_keycodes";

    public static final String XKBMAP_LAYOUT = "xkbmap_layout";

    public static final String YAML = "yaml";

    public static final String ZLIB = "zlib";

    private ClientCapabilities()
    {
        // nothing to to do
    }

    public class Metadata
    {

        private Metadata()
        {
            // nothing to do
        }

        public static final String ABOVE = "above";

        public static final String BELOW = "below";

        public static final String CLASS_INSTANCE = "class-instance";

        public static final String DECORATIONS = "decorations";

        public static final String FULLSCREEN = "fullscreen";

        public static final String HAS_ALPHA = "has-alpha";

        public static final String MAXIMIZED = "maximized";

        public static final String MODAL = "modal";

        public static final String OPACITY = "opacity";

        public static final String OVERRIDE_DIRECT = "override-redirect";

        public static final String SIZE_HINTS = "size-hints";

        public static final String TITLE = "title";

        public static final String TRANSIENT_FOR = "transient-for";

        public static final String WINDOW_TYPE = "window-type";

    }

}
