/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.client;

import java.util.Arrays;
import java.util.Collection;
import org.dussan.vaadin.dvirtual.xpra.packets.ClientPacket;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;

public class ClientClipboardTokenPacket
    extends ClientPacket
{

    private static final long serialVersionUID = -2777738256606448640L;

    private static final String BYTES = "bytes";

    private static final String CLIPBOARD = "CLIPBOARD";

    private static final String UTF8_STRING = "UTF8_STRING";

    private String clipboardData = null;

    public ClientClipboardTokenPacket()
    {
        super( PacketType.Client.CLIPBOARD_TOKEN.toString() );
    }

    public ClientClipboardTokenPacket( String clipboardData )
    {
        super( PacketType.Client.CLIPBOARD_TOKEN.toString() );
        this.clipboardData = clipboardData;
    }

    public String getClipboardData()
    {
        return clipboardData;
    }

    @Override
    public void packPacket( Collection<Object> packetData )
    {
        packetData.add( getPacketType() );
        packetData.add( CLIPBOARD );
        packetData.add( Arrays.asList( new String[0] ) );
        packetData.add( UTF8_STRING );
        packetData.add( UTF8_STRING );
        packetData.add( getClipboardData().length() );
        packetData.add( BYTES );
        packetData.add( getClipboardData() );
        packetData.add( false );
        packetData.add( true );
        packetData.add( true );
    }

}
