/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.client;

import java.util.Collection;

import org.dussan.vaadin.dvirtual.info.ClientProperties;
import org.dussan.vaadin.dvirtual.xpra.packets.ClientPacket;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;

public class ClientDesktopSizePacket
    extends ClientPacket
{

    private static final long serialVersionUID = -4858474187170070510L;

    private int dpi = 0;

    private int height = 0;

    private int width = 0;

    public ClientDesktopSizePacket()
    {
        super( PacketType.Client.DESKTOP_SIZE.toString() );
    }

    public ClientDesktopSizePacket( int width, int height, int dpi )
    {
        super( PacketType.Client.DESKTOP_SIZE.toString() );
        this.width = width;
        this.height = height;
        this.dpi = dpi;
    }

    public int getWidth()
    {
        return width;
    }

    public int getHeight()
    {
        return height;
    }

    @Override
    public void packPacket( Collection<Object> packetData )
    {
        packetData.add( getPacketType() );
        packetData.add( width );
        packetData.add( height );
        packetData.add( ClientProperties.getScreenSizes( width, height, dpi ) );
    }

}
