/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.server;

import java.util.Iterator;

import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;
import org.dussan.vaadin.dvirtual.xpra.packets.ServerPacket;

public class ServerPingEchoPacket
    extends ServerPacket
{

    private static final long serialVersionUID = 8727983319793767228L;

    private long timestamp = 0;

    private long l1 = 0;

    private long l2 = 0;

    private long l3 = 0;

    private int clientLatency = 0;

    public ServerPingEchoPacket()
    {
        super( PacketType.Server.PING_ECHO.toString() );
    }

    public int getClientLatency()
    {
        return clientLatency;
    }

    public long getL1()
    {
        return l1;
    }

    public long getL2()
    {
        return l2;
    }

    public long getL3()
    {
        return l3;
    }

    public long getTimestamp()
    {
        return timestamp;
    }

    @Override
    public void unpackPacket( Iterator<Object> packetData )
    {
        super.unpackPacket( packetData );
        timestamp = getLong( packetData.next() );
        l1 = getLong( packetData.next() );
        l2 = getLong( packetData.next() );
        l3 = getLong( packetData.next() );
        clientLatency = getInt( packetData.next() );
    }

}
