/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.server;

import java.util.Iterator;

import org.dussan.vaadin.dvirtual.xpra.info.PictureEncodingType;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;
import org.dussan.vaadin.dvirtual.xpra.packets.ServerPacket;

public class ServerWindowIconPacket
    extends ServerPacket
{

    private static final long serialVersionUID = -752015672141869833L;

    private int height = 0;

    private int width = 0;

    private int windowId = 0;

    private PictureEncodingType pictureEncodingType = null;

    private byte[] image = null;

    public ServerWindowIconPacket()
    {
        super( PacketType.Server.WINDOW_ICON.toString() );
    }

    public ServerWindowIconPacket( int windowId )
    {
        super( PacketType.Server.WINDOW_ICON.toString() );
        this.windowId = windowId;
    }

    public int getWindowId()
    {
        return windowId;
    }

    public int getWidth()
    {
        return width;
    }

    public int getHeight()
    {
        return height;
    }

    public PictureEncodingType getPictureEncodingType()
    {
        return pictureEncodingType;
    }

    public byte[] getImage()
    {
        return image;
    }

    @Override
    public void unpackPacket( Iterator<Object> packetData )
    {
        super.unpackPacket( packetData );
        windowId = getInt( packetData.next() );
        width = getInt( packetData.next() );
        height = getInt( packetData.next() );
        pictureEncodingType = PictureEncodingType.getType( getString( packetData.next() ) );
        image = getByteArray( packetData.next() );
    }

}
